#ifndef SLDA_H_
#define SLDA_H_

#include <stdio.h>
#include <gsl/gsl_vector.h>
#include <gsl/gsl_rng.h>

#include "util.h"
#include "doc.h"

struct strct_slda {

	int K, V;

	gsl_vector* alpha; //prior parameter for the topic mixing vector
	gsl_vector** mu; //mu[k] is the topic word distribution for the k-th topic
	gsl_vector* eta; //the regression model

};

strct_slda* alloc_slda(int K, int V);
void free_slda(strct_slda*);
void init_slda(strct_slda *slda, gsl_rng*);
strct_slda* read_slda(FILE *f);
void write_slda(strct_slda *slda, FILE *f);

strct_doc* gen_docs_from_slda(strct_slda* slda, int ndocs, int M, double sigma, gsl_rng*);

// Note: the h and z fields must be filled
void regularize_eta(gsl_vector* eta, int K, strct_doc* docs, int ndocs, double ref_mean, double ref_variance);

#endif
